package com.temboo.Library.Foursquare.Users;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
LatestCheckinForUser

Retrieves the latest check-in for an authenticated user.
*/
public class LatestCheckinForUser extends Choreography {

	/**
	Create a new instance of the LatestCheckinForUser Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public LatestCheckinForUser(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Foursquare/Users/LatestCheckinForUser"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return LatestCheckinForUserInputSet
	*/
	public LatestCheckinForUserInputSet newInputSet() {
		return new LatestCheckinForUserInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public LatestCheckinForUserResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new LatestCheckinForUserResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the LatestCheckinForUser
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class LatestCheckinForUserInputSet extends InputSet {
		/** 
		Set the value of the OauthToken input for this Choreo. 

		@param String - (required, string) The Foursquare API Oauth token string.
		*/
		public void set_OauthToken(String value) {
			this.setInput("OauthToken", value);
		}


		/** 
		Set the value of the ResponseFormat input for this Choreo. 

		@param String - (optional, string) The format that response should be in. Can be set to xml or json. Defaults to json.
		*/
		public void set_ResponseFormat(String value) {
			this.setInput("ResponseFormat", value);
		}


		/** 
		Set the value of the UserID input for this Choreo. 

		@param String - (optional, string) Only 'self' is supported at this moment by the Foursquare API. Defaults to: self.
		*/
		public void set_UserID(String value) {
			this.setInput("UserID", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the LatestCheckinForUser Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class LatestCheckinForUserResultSet extends ResultSet {
		public LatestCheckinForUserResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "City" output from this Choreo execution

		@return String - (string) The city that the venue is located in.
		*/
		public String get_City() {
			return this.getResultString("City");
		}
		/** 
		Retrieve the value for the "CreatedAt" output from this Choreo execution

		@return String - (date) The date associated with the user's latest check-in.
		*/
		public String get_CreatedAt() {
			return this.getResultString("CreatedAt");
		}
		/** 
		Retrieve the value for the "FormattedAddress" output from this Choreo execution

		@return String - (string) The formatted address of the venue associated with the user's latest check-in.
		*/
		public String get_FormattedAddress() {
			return this.getResultString("FormattedAddress");
		}
		/** 
		Retrieve the value for the "PostalCode" output from this Choreo execution

		@return String - (integer) The postal code of the venue.
		*/
		public String get_PostalCode() {
			return this.getResultString("PostalCode");
		}
		/** 
		Retrieve the value for the "State" output from this Choreo execution

		@return String - (string) The state that the venue is located in.
		*/
		public String get_State() {
			return this.getResultString("State");
		}
		/** 
		Retrieve the value for the "VenueID" output from this Choreo execution

		@return String - (string) The ID of the venue associated with the user's latest check-in.
		*/
		public String get_VenueID() {
			return this.getResultString("VenueID");
		}
		/** 
		Retrieve the value for the "VenueName" output from this Choreo execution

		@return String - (string) The name of the venue that the user last checked into.
		*/
		public String get_VenueName() {
			return this.getResultString("VenueName");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - The response from Foursquare. Corresponds to the ResponseFormat input. Defaults to JSON.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
