package com.temboo.Library.Google.ComputeEngine.Disks;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
InsertDisk

Creates a Persistent Disk resource in the specified project.
*/
public class InsertDisk extends Choreography {

	/**
	Create a new instance of the InsertDisk Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public InsertDisk(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Google/ComputeEngine/Disks/InsertDisk"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return InsertDiskInputSet
	*/
	public InsertDiskInputSet newInputSet() {
		return new InsertDiskInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public InsertDiskResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new InsertDiskResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the InsertDisk
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class InsertDiskInputSet extends InputSet {
		/** 
		Set the value of the DiskResource input for this Choreo. 

		@param String - (optional, json) A JSON string containing the disk resource properties you wish to set. This can be used as an alternative to individual inputs that represent disk properties.
		*/
		public void set_DiskResource(String value) {
			this.setInput("DiskResource", value);
		}


		/** 
		Set the value of the AccessToken input for this Choreo. 

		@param String - (optional, string) A valid access token retrieved during the OAuth process. This is required unless you provide the ClientID, ClientSecret, and RefreshToken to generate a new access token.
		*/
		public void set_AccessToken(String value) {
			this.setInput("AccessToken", value);
		}


		/** 
		Set the value of the ClientID input for this Choreo. 

		@param String - (conditional, string) The Client ID provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientID(String value) {
			this.setInput("ClientID", value);
		}


		/** 
		Set the value of the ClientSecret input for this Choreo. 

		@param String - (conditional, string) The Client Secret provided by Google. Required unless providing a valid AccessToken.
		*/
		public void set_ClientSecret(String value) {
			this.setInput("ClientSecret", value);
		}


		/** 
		Set the value of the Name input for this Choreo. 

		@param String - (required, string) The name of the persistent disk resource being created.
		*/
		public void set_Name(String value) {
			this.setInput("Name", value);
		}


		/** 
		Set the value of the Project input for this Choreo. 

		@param String - (required, string) The ID of a Google Compute project.
		*/
		public void set_Project(String value) {
			this.setInput("Project", value);
		}


		/** 
		Set the value of the RefreshToken input for this Choreo. 

		@param String - (conditional, string) An OAuth refresh token used to generate a new access token when the original token is expired. Required unless providing a valid AccessToken.
		*/
		public void set_RefreshToken(String value) {
			this.setInput("RefreshToken", value);
		}


		/** 
		Set the value of the SizeGB input for this Choreo. 

		@param String - (conditional, string) Size of the persistent disk, specified in GB. This is optional when using a SourceSnapshot or SourceImage, otherwise it is required.
		*/
		public void set_SizeGB(String value) {
			this.setInput("SizeGB", value);
		}


		/** 
		Set the value of the SourceImage input for this Choreo. 

		@param String - (conditional, string) The URL for the source image to apply to the disk. This is required if SizeGB or SourceSnapshot is not provided.
		*/
		public void set_SourceImage(String value) {
			this.setInput("SourceImage", value);
		}


		/** 
		Set the value of the SourceSnapshot input for this Choreo. 

		@param String - (conditional, string) The source snapshot used to create this disk. This is required if SizeGB and SourceImage are not specified.
		*/
		public void set_SourceSnapshot(String value) {
			this.setInput("SourceSnapshot", value);
		}


		/** 
		Set the value of the Zone input for this Choreo. 

		@param String - (required, string) The name of the zone associated with this request.
		*/
		public void set_Zone(String value) {
			this.setInput("Zone", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the InsertDisk Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class InsertDiskResultSet extends ResultSet {
		public InsertDiskResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "NewAccessToken" output from this Choreo execution

		@return String - (string) Contains a new AccessToken when the RefreshToken is provided.
		*/
		public String get_NewAccessToken() {
			return this.getResultString("NewAccessToken");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Google.
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
