package com.temboo.Library.MailChimp;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ListBatchSubscribeCSV

Adds or updates multiple subscribers in a given CSV file.
*/
public class ListBatchSubscribeCSV extends Choreography {

	/**
	Create a new instance of the ListBatchSubscribeCSV Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ListBatchSubscribeCSV(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/MailChimp/ListBatchSubscribeCSV"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ListBatchSubscribeCSVInputSet
	*/
	public ListBatchSubscribeCSVInputSet newInputSet() {
		return new ListBatchSubscribeCSVInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ListBatchSubscribeCSVResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ListBatchSubscribeCSVResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ListBatchSubscribeCSV
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ListBatchSubscribeCSVInputSet extends InputSet {
		/** 
		Set the value of the CSVFile input for this Choreo. 

		@param String - (conditional, multiline) The list of subscriber email addresses to unsubscribe in CSV format.
		*/
		public void set_CSVFile(String value) {
			this.setInput("CSVFile", value);
		}


		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Mailchimp
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the DoubleOptIn input for this Choreo. 

		@param Boolean - (conditional, boolean) Flag to control whether a double opt-in confirmation message is sent. Specify '1' (true) or '0' (false). Defaults to 0.
		*/
		public void set_DoubleOptIn(Boolean value) {
			this.setInput("DoubleOptIn", value);
		}

		/** 
		Set the value of the DoubleOptIn input for this Choreo as a String. 

		@param String - (conditional, boolean) Flag to control whether a double opt-in confirmation message is sent. Specify '1' (true) or '0' (false). Defaults to 0.
		*/
		public void set_DoubleOptIn(String value) {
			this.setInput("DoubleOptIn", value);	
		}
		/** 
		Set the value of the EmailType input for this Choreo. 

		@param String - (optional, string) Must be one of 'text', 'html', or 'mobile'. Defaults to html.
		*/
		public void set_EmailType(String value) {
			this.setInput("EmailType", value);
		}


		/** 
		Set the value of the ListId input for this Choreo. 

		@param String - (required, string) The id of the Mailchimp list associated with the email addresses to subscribe.
		*/
		public void set_ListId(String value) {
			this.setInput("ListId", value);
		}


		/** 
		Set the value of the ReplaceInterests input for this Choreo. 

		@param Boolean - (optional, boolean) A flag to determine whether to replace the interest groups with the groups provided or add the provided groups to the member's interest groups. Specify '1' (true) or '0' (false). Defaults to 1.
		*/
		public void set_ReplaceInterests(Boolean value) {
			this.setInput("ReplaceInterests", value);
		}

		/** 
		Set the value of the ReplaceInterests input for this Choreo as a String. 

		@param String - (optional, boolean) A flag to determine whether to replace the interest groups with the groups provided or add the provided groups to the member's interest groups. Specify '1' (true) or '0' (false). Defaults to 1.
		*/
		public void set_ReplaceInterests(String value) {
			this.setInput("ReplaceInterests", value);	
		}
		/** 
		Set the value of the SupressErrors input for this Choreo. 

		@param Boolean - (optional, boolean) Whether or not to suppress errors that arise from attempting to add/update a subscriber. Defaults to 0 (false). Set to 1 (true) to supress errors.
		*/
		public void set_SupressErrors(Boolean value) {
			this.setInput("SupressErrors", value);
		}

		/** 
		Set the value of the SupressErrors input for this Choreo as a String. 

		@param String - (optional, boolean) Whether or not to suppress errors that arise from attempting to add/update a subscriber. Defaults to 0 (false). Set to 1 (true) to supress errors.
		*/
		public void set_SupressErrors(String value) {
			this.setInput("SupressErrors", value);	
		}
		/** 
		Set the value of the UpdateExisting input for this Choreo. 

		@param Boolean - (conditional, boolean) Indicates that if the email already exists, this request will perform an update instead of an insert. Specify '1' (true) or '0' (false). Defaults to 1.
		*/
		public void set_UpdateExisting(Boolean value) {
			this.setInput("UpdateExisting", value);
		}

		/** 
		Set the value of the UpdateExisting input for this Choreo as a String. 

		@param String - (conditional, boolean) Indicates that if the email already exists, this request will perform an update instead of an insert. Specify '1' (true) or '0' (false). Defaults to 1.
		*/
		public void set_UpdateExisting(String value) {
			this.setInput("UpdateExisting", value);	
		}
		/** 
		Set the value of the VaultFile input for this Choreo. 

		@param TembooPath - A path to a csv file in the vault containing the email addresses to unsubscribe. Can be used as an alternative to the CSVFile input.
		*/

	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ListBatchSubscribeCSV Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ListBatchSubscribeCSVResultSet extends ResultSet {
		public ListBatchSubscribeCSVResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "ErrorList" output from this Choreo execution

		@return String - (multiline) A list of emails that were not successfully subscribed.
		*/
		public String get_ErrorList() {
			return this.getResultString("ErrorList");
		}
		/** 
		Retrieve the value for the "SuccessList" output from this Choreo execution

		@return String - (multiline) A list of email successfully subscribed.
		*/
		public String get_SuccessList() {
			return this.getResultString("SuccessList");
		}
	}
	
}
