package com.temboo.Library.Plotly;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
ExtendTimeSeries

Extends the specified time series graph by plotting a single addition point.
*/
public class ExtendTimeSeries extends Choreography {

	/**
	Create a new instance of the ExtendTimeSeries Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public ExtendTimeSeries(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Plotly/ExtendTimeSeries"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return ExtendTimeSeriesInputSet
	*/
	public ExtendTimeSeriesInputSet newInputSet() {
		return new ExtendTimeSeriesInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public ExtendTimeSeriesResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new ExtendTimeSeriesResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the ExtendTimeSeries
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class ExtendTimeSeriesInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Plotly.
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the FileName input for this Choreo. 

		@param String - (required, string) The file name of your Plotly graph. If the file is nested within a directory, you can specify a path here (e.g., myFolder/myPlot).
		*/
		public void set_FileName(String value) {
			this.setInput("FileName", value);
		}


		/** 
		Set the value of the TimeZone input for this Choreo. 

		@param String - (optional, string) If a value is not passed to the Timestamp input, the current is generated for you. When using this feature, you can indicate the desired time zone using this input. The default TimeZone is UTC.
		*/
		public void set_TimeZone(String value) {
			this.setInput("TimeZone", value);
		}


		/** 
		Set the value of the Title input for this Choreo. 

		@param String - (optional, string) The title of the graph.
		*/
		public void set_Title(String value) {
			this.setInput("Title", value);
		}


		/** 
		Set the value of the Username input for this Choreo. 

		@param String - (required, string) A valid Plotly username.
		*/
		public void set_Username(String value) {
			this.setInput("Username", value);
		}


		/** 
		Set the value of the WorldReadable input for this Choreo. 

		@param Boolean - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
		*/
		public void set_WorldReadable(Boolean value) {
			this.setInput("WorldReadable", value);
		}

		/** 
		Set the value of the WorldReadable input for this Choreo as a String. 

		@param String - (optional, boolean) When set to true, the graph is viewable by anyone who has the link. If false (the default), the graph is only viewable in the owner's Plotly account.
		*/
		public void set_WorldReadable(String value) {
			this.setInput("WorldReadable", value);	
		}
		/** 
		Set the value of the XValue input for this Choreo. 

		@param String - (conditional, date) The "x" coordinate timestamp to be plotted on the graph in the format YYYY-MM-DD HH:MM:SS. If not provided, this defaults to NOW().
		*/
		public void set_XValue(String value) {
			this.setInput("XValue", value);
		}


		/** 
		Set the value of the YValue input for this Choreo. 

		@param String - (required, string) The "y" coordinate value associated with the specified timestamp.
		*/
		public void set_YValue(String value) {
			this.setInput("YValue", value);
		}


	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the ExtendTimeSeries Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class ExtendTimeSeriesResultSet extends ResultSet {
		public ExtendTimeSeriesResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "URL" output from this Choreo execution

		@return String - (string) The Plotly URL for the graph.
		*/
		public String get_URL() {
			return this.getResultString("URL");
		}
		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Plotly
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
