package com.temboo.Library.Stripe.Invoices;

/*
Copyright 2014 Temboo, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

import org.json.JSONArray;
import org.json.JSONObject;
import org.json.JSONException;
import java.math.BigDecimal;
import com.temboo.core.Choreography;
import com.temboo.core.Choreography.ResultSet;
import com.temboo.core.Choreography.InputSet;
import com.temboo.core.TembooException;
import com.temboo.core.TembooPath;
import com.temboo.core.TembooSession;

/** 
RetrieveInvoiceLineItems

Retrieves a full list of line items contained in an invoice.
*/
public class RetrieveInvoiceLineItems extends Choreography {

	/**
	Create a new instance of the RetrieveInvoiceLineItems Choreo. A TembooSession object, containing a valid
	set of Temboo credentials, must be supplied.
	*/
	public RetrieveInvoiceLineItems(TembooSession session) {
		super(session, TembooPath.pathFromStringNoException("/Library/Stripe/Invoices/RetrieveInvoiceLineItems"));
	}


	/** 
	Obtain an InputSet object, used to define inputs for an execution of this Choreo.
	
	@return RetrieveInvoiceLineItemsInputSet
	*/
	public RetrieveInvoiceLineItemsInputSet newInputSet() {
		return new RetrieveInvoiceLineItemsInputSet();
	}
	
	
	/**
	 * Execute the Choreo using the specified InputSet as parameters, wait for the Choreo to complete 
	 * and return a ResultSet containing the execution results.
	 * @param choreoInputs
	 * @return
	 * @throws TembooException
	 */
	 @Override
	public RetrieveInvoiceLineItemsResultSet execute(InputSet choreoInputs) throws TembooException {
		JSONObject result = super.executeWithResults(choreoInputs);
		return new RetrieveInvoiceLineItemsResultSet(result);
	}
	
	
	/**
		An InputSet with methods appropriate for specifying the inputs to the RetrieveInvoiceLineItems
        Choreo. The InputSet object is used to specify input parameters when executing this choreo.
	*/
	public static class RetrieveInvoiceLineItemsInputSet extends InputSet {
		/** 
		Set the value of the APIKey input for this Choreo. 

		@param String - (required, string) The API Key provided by Stripe
		*/
		public void set_APIKey(String value) {
			this.setInput("APIKey", value);
		}


		/** 
		Set the value of the Count input for this Choreo. 

		@param Integer - (optional, integer) The number of line items to return
		*/
		public void set_Count(Integer value) {
			this.setInput("Count", value);
		}

		/** 
		Set the value of the Count input for this Choreo as a String. 

		@param String - (optional, integer) The number of line items to return
		*/
		public void set_Count(String value) {
			this.setInput("Count", value);	
		}
		/** 
		Set the value of the CustomerID input for this Choreo. 

		@param String - (optional, string) In the case of upcoming invoices, the customer of the upcoming invoice is required. In other cases it is ignored.
		*/
		public void set_CustomerID(String value) {
			this.setInput("CustomerID", value);
		}


		/** 
		Set the value of the InvoiceID input for this Choreo. 

		@param String - (required, string) The id of the invoice containing the line items to return
		*/
		public void set_InvoiceID(String value) {
			this.setInput("InvoiceID", value);
		}


		/** 
		Set the value of the Offset input for this Choreo. 

		@param Integer - (optional, integer) The offset into the list of line items to start returning from, with 0 being the most recent
		*/
		public void set_Offset(Integer value) {
			this.setInput("Offset", value);
		}

		/** 
		Set the value of the Offset input for this Choreo as a String. 

		@param String - (optional, integer) The offset into the list of line items to start returning from, with 0 being the most recent
		*/
		public void set_Offset(String value) {
			this.setInput("Offset", value);	
		}
	}
	
	
	/**
		A ResultSet with methods tailored to the values returned by the RetrieveInvoiceLineItems Choreo.
        The ResultSet object is used to retrieve the results of a Choreo execution.
	*/
	public static class RetrieveInvoiceLineItemsResultSet extends ResultSet {
		public RetrieveInvoiceLineItemsResultSet(JSONObject doc) throws TembooException {
			super(doc);
		}

		/** 
		Retrieve the value for the "Response" output from this Choreo execution

		@return String - (json) The response from Stripe
		*/
		public String get_Response() {
			return this.getResultString("Response");
		}
	}
	
}
